cbuffer constants : register(b0)
{
    float barrelPower;
    float imageScale;
};

struct VS_Input {
    float2 pos : POS;
    float2 uv : TEX;
};

struct VS_Output {
    float4 pos : SV_POSITION;
    float2 uv : TEXCOORD;
};

Texture2D    mytexture[2] : register(t0);
SamplerState mysampler : register(s0);


VS_Output vs_main(VS_Input input)
{
    VS_Output output;
    output.pos = float4(input.pos, 0.0f, 1.0f);
    output.uv = input.uv;
    return output;
}

float4 ps_main(VS_Output input) : SV_Target
{
    //float2 scale2 = (1.5, 1.2);

    if (barrelPower != 0.0){
        float rescale = 1.0 - (0.25 * barrelPower);
        float2 texcoord = (input.uv  - 0.5) * imageScale;
        float rsq = texcoord.x * texcoord.x + texcoord.y * texcoord.y;
        texcoord = texcoord + (texcoord * (barrelPower * rsq));
        texcoord *= rescale;
        //texcoord /= scale2;

        if (abs(texcoord.x) > 0.5 || abs(texcoord.y) > 0.5) {
            float4 col = float4(0, 0, 0, 1);

            return col;
        }
        else {
            texcoord += 0.5;
            //texcoord /= scale2;

            float4 texColor = mytexture[0].Sample(mysampler, texcoord);
            float4 intensityColor = mytexture[1].Sample(mysampler, texcoord);
            
            return texColor * intensityColor;

        }
    }
    else {
        float4 texColor = mytexture[0].Sample(mysampler, input.uv);
        float4 intensityColor = mytexture[1].Sample(mysampler, input.uv);

       // float4 newtexColor = float4(texColor.x, texColor.y, texColor.z, 1);

        return texColor * intensityColor;
    }

}